@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -49,7 +47,7 @@ STATUS_FA_ICON_MAP = {'btn-success': "fa-check",
 
 
 def get_icon(status):
-    return STATUS_FA_ICON_MAP.get(status,  "fa-question-circle")
+    return STATUS_FA_ICON_MAP.get(status, "fa-question-circle")
 
 
 priorities = [
@@ -104,7 +102,7 @@ def get_dashboard_links(request):
                 return value
         return settings.DEFAULT_LINKS
     except Exception:
-        LOG.warn("Failed to parse dashboard links by project, returning defaults.")
+        LOG.warning("Failed to parse dashboard links by project, returning defaults.")
         pass
     #
     # Extra safety here -- should have got a match somewhere above,
@@ -154,7 +152,7 @@ def get_monitoring_services(request):
                 return value
         return settings.MONITORING_SERVICES
     except Exception:
-        LOG.warn("Failed to parse monitoring services by project, returning defaults.")
+        LOG.warning("Failed to parse monitoring services by project, returning defaults.")
         pass
     #
     # Extra safety here -- should have got a match somewhere above,
@@ -305,7 +303,7 @@ class MonascaProxyView(TemplateView):
                            metrics_measurement_list(request,
                                                     **req_kwargs)}
         if not results:
-            LOG.warn("There was a request made for the path %s that"
+            LOG.warning("There was a request made for the path %s that"
                      " is not supported." % restpath)
             results = {}
         return HttpResponse(json.dumps(results),
@@ -368,11 +366,14 @@ class KibanaProxyView(generic.View):
 
         else:
             status = response.getcode()
-            return http.StreamingHttpResponse(
+            proxy_response = http.StreamingHttpResponse(
                 proxy_stream_generator(response),
                 status=status,
                 content_type=response.headers['content-type']
             )
+            if 'set-cookie' in response.headers:
+                proxy_response['set-cookie'] = response.headers['set-cookie']
+            return proxy_response
 
     @csrf_exempt
     def dispatch(self, request, url):
@@ -392,7 +393,8 @@ class KibanaProxyView(generic.View):
         # passing kbn version explicitly for kibana >= 4.3.x
         headers = {
             'X-Auth-Token': request.user.token.id,
-            'kbn-version': request.META.get('HTTP_KBN_VERSION', '')
+            'kbn-version': request.META.get('HTTP_KBN_VERSION', ''),
+            'Cookie': request.META.get('HTTP_COOKIE', '')
         }
 
         return self.read(request.method, url, request.body, headers)
